@@ -20,6 +20,7 @@ import traceback
 import collections
 from itertools import groupby
 from operator import itemgetter
+from collections import OrderedDict
 
 from tpDcc.libs.python import strings
 
@@ -876,3 +877,41 @@ def from_list_to_nested_dict(input_arg, separator='/'):
                 action_comp.pop('children')
 
     return result
+
+
+def float_range(start, stop=None, step=None):
+    """
+    Function that returns a generator that allow us to do a range using float numbers
+    :param start: float
+    :param stop: float
+    :param step: float
+    :return: generator
+    """
+
+    start = float(start)
+    if stop is None:
+        stop = start + 0.0
+        start = 0.0
+    if step is None:
+        step = 1.0
+
+    count = 0
+    while True:
+        temp = float(start + count * step)
+        if step > 0 and temp >= stop:
+            break
+        elif step < 0 and temp <= stop:
+            break
+        yield temp
+        count += 1
+
+
+def order_dict_by_list_of_keys(dict_to_order, keys):
+    """
+    Order dictionary taking into account the order of the keys in a list
+    :param dict_to_order: dict
+    :param keys: list(str)
+    :return: dict
+    """
+
+    return OrderedDict([(key, dict_to_order[key]) for key in keys if key in dict_to_order])
